﻿using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;


//====================================================
// Описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
//====================================================


namespace WpfMeasureText
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            List<string> fontNames = Fonts.SystemFontFamilies.Select(p => p.Source).ToList();
            fontNames.Sort();

            foreach (string s in fontNames)
            {
                _ = FontsList.Items.Add(s);
            }

            _ = FontStylesList.Items.Add(FontStyles.Normal);
            _ = FontStylesList.Items.Add(FontStyles.Italic);
            _ = FontStylesList.Items.Add(FontStyles.Oblique);

            MyDrawCanvas.ChangeDraw += MyDrawCanvas_ChangeDraw;
        }


        private void Grid_Loaded(object sender, RoutedEventArgs e)
        {
            MyDrawCanvas.Text = textBox1.Text;
            InvalidateVisual();
        }


        private void MyDrawCanvas_ChangeDraw(MyCode.ChangeDrawTextEventArgs args)
        {
            labOverhangLeading.Content = args.OverhangLeading;
            labWidth.Content = args.Width;
            labOverhangTrailing.Content = args.OverhangTrailing;
            labBaseline.Content = args.Baseline;
            labHeight.Content = args.Height;
            labExtent.Content = args.Extent;
            labOverhangAfter.Content = args.OverhangAfter;
            labLineHeight.Content = args.LineHeight;
            labNumberLines.Content = args.NumberLines;
        }


        private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            Slider slider = sender as Slider;

            if (slider == FontSizeSlider)
            {
                double fontsize = slider.Value;

                MyDrawCanvas.FontSize = fontsize;
                if (FontSizeLabel != null)
                {
                    FontSizeLabel.Content = fontsize.ToString();
                }
            }

            if (slider == LineHeightSlider)
            {
                double lineheight = slider.Value;

                MyDrawCanvas.LineHeight = lineheight;
                if (LineHeightLabel != null)
                {
                    LineHeightLabel.Content = lineheight.ToString();
                }
            }
        }


        private void FontsList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ListBox listBox = sender as ListBox;

            if (listBox == FontsList)
            {
                MyDrawCanvas.FamilyName = listBox.SelectedItem.ToString();
            }

            if (listBox == FontStylesList)
            {
                MyDrawCanvas.FontStyle = (FontStyle)listBox.SelectedItem;
            }
        }

        private void textBox1_TextChanged(object sender, TextChangedEventArgs e)
        {
            if (MyDrawCanvas != null)
                MyDrawCanvas.Text = textBox1.Text;
        }
    }
}
